pub enum CacheResponse<R: Responder<'static>> {
Public {
responder: R,
max_age: u32,
must_revalidate: bool,
},
Private {
responder: R,
max_age: u32,
},
NoCache(R),
NoStore(R),
NoCacheControl(R),
}Expand description
The responder with a Cache-Control header.
Variants
Public
Private
NoCache(R)
NoStore(R)
NoCacheControl(R)
Implementations
sourceimpl<R: Responder<'static>> CacheResponse<R>
impl<R: Responder<'static>> CacheResponse<R>
sourcepub fn public_only_release(
responder: R,
_max_age: u32,
_must_revalidate: bool
) -> CacheResponse<R>
pub fn public_only_release(
responder: R,
_max_age: u32,
_must_revalidate: bool
) -> CacheResponse<R>
Use public cache only when this program is built on the release mode.
sourcepub fn private_only_release(responder: R, _max_age: u32) -> CacheResponse<R>
pub fn private_only_release(responder: R, _max_age: u32) -> CacheResponse<R>
Use private cache only when this program is built on the release mode.